import cartopy.crs as ccrs
import matplotlib as mpl
import matplotlib.image as mpimg
import matplotlib.pyplot as plt
from   cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter
import cartopy.feature as  cfeature
import os
import shutil

from DDRW import subprogs_cartopy
from DDRW import gsitile as gsi
from DHDL import subprogs

def GSI_mk1fig(slon,elon,slat,elat,data,V2D,colormap,clevels,\
               FigTitle,args,windU2D='N',windV2D='N',\
               scaleUV=0.0,maxUV=0.0):

    FigsizeFix = 0   # 0-> Fitting for Original PNG size
                     # 1-> Fitting for user's demand size
    zoom = args.ZoomLevel
    tile_type = "std"
    out  = args.OUTFIG
    alpha = float(args.Transparent)
    map_org = "./background.png"

    if args.Animate:
        if not os.path.exists(map_org):
            print("start making GSI map")
            gsi.gsitile2png(tile_type,zoom,slon,elon,slat,elat,out)
            print("done for making GSI map")
            shutil.copy(out,map_org)
        else:
            shutil.copy(map_org,out)    
    else:            
        print("start making GSI map")
        gsi.gsitile2png(tile_type,zoom,slon,elon,slat,elat,out)
        print("done for making GSI map")

    img = mpimg.imread(out)

    if FigsizeFix == 1:
        Fxsiz = 8
        Fysiz,shrink_v = subprogs_cartopy.set_para(slon,elon,slat,elat,Fxsiz)
        fig = plt.figure(figsize=(Fxsiz,Fysiz))
    else:
        img_height,img_width = img.shape[:2]
        desired_dpi = 100
        Fxsiz = img_width/desired_dpi
        Fysiz = img_height/desired_dpi
        fig = plt.figure(figsize=(Fxsiz,Fysiz), dpi=desired_dpi)
        shrink_v = 0.5
        
    # configure for a single figure in the whole figure domain
    ax  = fig.add_subplot(111,projection=
                          ccrs.PlateCarree())    

    ax.imshow(img, extent=[slon, elon, slat, elat], \
              origin='upper', transform=ccrs.PlateCarree())

    contourf = ax.contourf(
        data["LON"],data["LAT"],V2D,transform=ccrs.PlateCarree(),
        cmap=colormap,extend="both",levels=clevels,alpha=alpha)
    
    plt.colorbar(contourf,shrink=shrink_v, pad= 0.03)

    ## wind ###
    if args.WIND is not None:
        if int(args.WIND) == 0:  # vector
            Q=ax.quiver(windU2D["LON"].values,windU2D["LAT"].values,\
                        windU2D,windV2D,transform=ccrs.PlateCarree(),\
                        units='inches',scale=scaleUV)
            # location of reference vector
            X1 = elon - (elon-slon) *0.10
            Y1 = elat + (elat-slat) *0.10
            ax.quiverkey(Q,X1,Y1,maxUV,str(maxUV)+"m/s",
                         labelpos='E',coordinates='data')

        elif int(args.WIND) == 1: # yabane
            Q=ax.barbs(windU2D["LON"].values,windU2D["LAT"].values,\
                       windU2D,windV2D,transform=ccrs.PlateCarree(),\
                       length=4)        
            
    # set drawing range lon.lat
    ax.set_extent([slon,elon,slat,elat],crs=ccrs.PlateCarree())

    # setting for xlabel and ylabel
    (xticks, yticks) = subprogs.set_ticks(slon,elon,slat,elat)

    ax.set_xticks(xticks,crs=ccrs.PlateCarree())
    ax.set_yticks(yticks,crs=ccrs.PlateCarree())
    lon_formatter = LongitudeFormatter(zero_direction_label=True)
    lat_formatter = LatitudeFormatter()
    ax.xaxis.set_major_formatter(lon_formatter)
    ax.yaxis.set_major_formatter(lat_formatter)

    # Draw Fig Title
    ax.set_title(FigTitle,loc="center")
    
    # Boundary for prefecture
    #countries_10m  = cfeature.NaturalEarthFeature('cultural',
    #                 'admin_1_states_provinces_lines',
    #                 '10m', edgecolor='black',facecolor='none')
    
    # draw coastline
    #ax.coastlines()

    # draw boundary of prefecture
    #ax.add_feature(countries_10m, linestyle=':', linewidth=0.5, alpha=0.8)

    # plot observation location
    #xobs = 141.523
    #yobs =  35.9
    #xobs = 141.703
    #yobs =  35.9
    #ax.plot(xobs,yobs,markersize=10, marker='x',color='black')

    
    if args.OUTFIG is not None:
        plt.savefig(args.OUTFIG)

    # draw figure
    if not args.Animate:
        plt.show()
