import xarray as xr
import numpy as np

def mabiki2D_xarray(data,factor):

    ndim = len(data.dims)
    if ndim != 2:
        print("not 2Dimension")
        exit
    dimnameY = data.dims[0]
    dimnameX = data.dims[1]
    
    Y = data[dimnameY].values
    X = data[dimnameX].values    
    Y2 = Y[::factor]
    X2 = X[::factor]
    dimnames = [dimnameY,dimnameX]
    coords_info = {dimnameY : Y2, dimnameX : X2}
    YNUM, XNUM = data.shape
    XNUM2 = len(X2)
    YNUM2 = len(Y2)
    
    resize_data = np.empty((YNUM2,XNUM2),dtype=data.dtype)
    j2 = 0
    for j in range(0,YNUM,factor):
        x_data = data[j,:].values
        x2_data = x_data[::factor]
        resize_data[j2,:] = x2_data
        j2=j2+1
        
    outxarray = xr.DataArray(resize_data,dims=dimnames,coords=coords_info)
    return outxarray

def make_profile_xarray(data,Z1D,xy,dlon,missing_value=-999999.9):
    
    ZNUM = len(Z1D)
    XNUM = len(xy)

    data = np.transpose(data)
    for j,aa in enumerate(data):
        for i, bb in enumerate(aa):
            if bb < missing_value+1 or bb < -999999.9:
                data[j][i] = np.nan
            else:
                pass
                
    dimnameX = "DISTANCE"
    dimnameZ = "LEV"
    dimnames = [dimnameZ,dimnameX]

    xydis = [0.e0 for i in range(XNUM)] ## initilize
    for m, (xx,yy) in enumerate(xy):
        if(m ==0):
            x0 = xx
            y0 = yy
        disx = (xx-x0)/dlon
        disy = (yy-y0)/0.009
        xydis[m] = np.sqrt(disx*disx + disy*disy)

    coords_info = {dimnameZ : Z1D, dimnameX : xydis}
    outxarray = xr.DataArray(data,dims=dimnames,coords=coords_info)
    return outxarray
