import os
import argparse
import xarray as xr

from DHDL import subprogs 
from DHDL import subprogs_xarray 
from DHDL import get1varUV
from DDRW import GSI_mk1fig

####################
# developer shimizu shingo, NIED
##############################

def main():

    ## control for command line argument ##########################
    parser = argparse.ArgumentParser(description='draw netcdf')
    parser.add_argument('arg1',help='input file setting')
    parser.add_argument('arg2',help='variable setting')
    parser.add_argument('-t','--timenum',help='time slide from initial time')
    parser.add_argument('-T','--TIME',help='YYYY-M2-D2_H2:M2:S2(UTC)')
    parser.add_argument('-z','--levelnum',help='level number to be drawn')
    parser.add_argument('-Z','--LEV',help='level (m) to be drawn')
    parser.add_argument('-O','--OUTFIG',help='output file name')
    parser.add_argument('-W','--WIND',help='opt for wind draw 0:vector 1:barb')
    parser.add_argument('-WT','--WINDTHIN',\
                        help='data thinning out for vector, set mabiki factor')
    parser.add_argument('-CT','--ColorType',\
                        help='To use preset colormap, select colortype')
    parser.add_argument('-AR','--AutoRange',action='store_true',\
                        help='1: Manually set color range')
    parser.add_argument('-ZL','--ZoomLevel',help='Zoom-level for GSI map')
    parser.add_argument('-TL','--Transparent',help='Transparent for map')
    parser.add_argument('-ANM','--Animate', action='store_true',\
                        help='save backgroud PNG for making anime')
    parser.add_argument('-JPN','--JapanTime',action='store_true',\
                        help='Time is converted into ')

    args = parser.parse_args()
    ####################################################################
    infile = args.arg1
    if not os.path.exists(infile):
        print ("infile does not exist \n",infile)
        exit(1)

    #open NETCDF as XARRAY
    data     = xr.open_dataset(infile)

    # get variable name
    varname  = args.arg2

    if args.OUTFIG is None:
        print("OUTFIG must be set")
        exit(1)

    if args.ZoomLevel is None:
        print("ZoomLevel must be set")
        exit(1)

    if args.Transparent is None:
        print("Transparent must be set")
        exit(1)
    
    #############################################################
    # check if the variable is included in NETCDF 
    subprogs.check_variable(data,varname,args)
    #############################################################
    
    #############################################################
    # get 2Dim for one variable with U and V wind vecotr    #####
    #############################################################
    if args.WIND is not None:
        V2D,colormap,clevels,windU2D,windV2D,scaleUV,maxUV,TTT,ZZZ = \
            get1varUV.get1varUV(data,varname,args)
    else:
        V2D,colormap,clevels,TTT,ZZZ = get1varUV.get1varUV(data,varname,args)

    #############################################################
    # draw region setting and check the domain 
    #############################################################
    slon = 138
    elon = 139
    slat = 35.2
    elat = 35.8
    
    LLL = subprogs.check_draw_domain(slon,elon,slat,elat,data)
    if LLL[0] == -1:
        slon = LLL[1]
        elon = LLL[2]
        slat = LLL[3]
        elat = LLL[4]

    #############################################################

    #################################################################
    # description for figure is saved as "figure title" 
    FigTitle = subprogs.set_figtitle(args,data,infile,varname,TTT,ZZZ)
    ################################################################

    ### DRAW 1 figure by Cartopy over GSI map ###################
    if args.WIND is not None:
        GSI_mk1fig.GSI_mk1fig(slon,elon,slat,elat,data,V2D,\
                              colormap,clevels,FigTitle,args,\
                              windU2D,windV2D,scaleUV,maxUV)
    else:
        GSI_mk1fig.GSI_mk1fig(slon,elon,slat,elat,data,V2D,\
                              colormap,clevels,FigTitle,args)

    
if __name__ == "__main__":
    main()
